@@ -13,7 +13,7 @@ use Test::BDD::Cucumber::Definitions::Validator qw(:all);
 use Test::More;
 use Try::Tiny;
 
-our $VERSION = '0.33';
+our $VERSION = '0.34';
 
 our @EXPORT_OK = qw(Struct);
 
@@ -92,13 +92,13 @@ sub read_zip_archive_members_as_list {
     # Clean data
     S->{_Struct}->{data} = undef;
 
-    my @members = S->{zip}->{archive}->memberNames();
+    my @members = S->{Zip}->member_names();
 
     S->{_Struct}->{data} = \@members;
 
     pass('Zip archive members was read as list');
 
-    return;
+    return 1;
 }
 
 sub data_element_eq {
